@@ -1,5 +1,5 @@
 package Net::Cisco::FMC::v1;
-$Net::Cisco::FMC::v1::VERSION = '0.009001';
+$Net::Cisco::FMC::v1::VERSION = '0.009002';
 # ABSTRACT: Cisco Firepower Management Center (FMC) API version 1 client library
 
 use 5.024;
@@ -268,7 +268,10 @@ sub login($self) {
             $res->response->header('x-auth-access-token'));
     }
     else {
-        croak($res->data->{error}->{messages}[0]->{description});
+        my $errmsg = ref $res->data eq 'HASH'
+            ? $res->data->{error}->{messages}[0]->{description}
+            : $res->data;
+        croak($errmsg);
     }
 }
 
@@ -721,7 +724,7 @@ Net::Cisco::FMC::v1 - Cisco Firepower Management Center (FMC) API version 1 clie
 
 =head1 VERSION
 
-version 0.009001
+version 0.009002
 
 =head1 SYNOPSIS
 
